@@ -13,15 +13,23 @@
 #include <QWidget>
 #include <memory>
 
+class PartsConfig;
+
 
 /*!
   \brief パーツ描画ウィジット
 */
 class PartsDrawWidget : public QWidget {
 
+  PartsDrawWidget(const PartsDrawWidget& rhs);
+  PartsDrawWidget& operator = (const PartsDrawWidget& rhs);
+
   struct pImpl;
   std::auto_ptr<pImpl> pimpl;
 
+  /*!
+    \brief
+  */
   void paintEvent(QPaintEvent* event);
 
 public:
@@ -32,6 +40,20 @@ public:
   */
   PartsDrawWidget(QWidget* parent = 0);
   ~PartsDrawWidget(void);
+
+  /*!
+    \brief
+
+    \param parts [i]
+  */
+  void updatePreview(const PartsConfig& parts);
+
+  /*!
+    \brief
+
+    \param file_name [i]
+  */
+  bool outputPixmap(const QString& file_name);
 };
 
 #endif /* !PARTS_DRAW_WIDGET_H */
