@@ -30,6 +30,11 @@ class PartsGeneratorWindow
 
 private slots:
   void aboutApplication(void);
+  void newFile(void);
+  void openFile(void);
+  void saveFile(void);
+  void update(void);
+  void outputPixmap(void);
 
 public:
   PartsGeneratorWindow(void);
