@@ -4,47 +4,47 @@
 <context>
     <name>PartsGeneratorWindow</name>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="124"/>
+        <location filename="PartsGeneratorWindow.cpp" line="138"/>
         <source>About parts_generator</source>
         <translation>Parts Generator について</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="128"/>
+        <location filename="PartsGeneratorWindow.cpp" line="142"/>
         <source>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Theme making sub tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Parts generator&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成補助ツール&lt;/p&gt;&lt;p&gt;バグ報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="80"/>
+        <location filename="PartsGeneratorWindow.cpp" line="96"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="81"/>
+        <location filename="PartsGeneratorWindow.cpp" line="97"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="84"/>
+        <location filename="PartsGeneratorWindow.cpp" line="100"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="85"/>
+        <location filename="PartsGeneratorWindow.cpp" line="101"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="88"/>
+        <location filename="PartsGeneratorWindow.cpp" line="104"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="89"/>
+        <location filename="PartsGeneratorWindow.cpp" line="105"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindow.cpp" line="98"/>
+        <location filename="PartsGeneratorWindow.cpp" line="114"/>
         <source>Font</source>
         <translation>フォント</translation>
     </message>
@@ -57,134 +57,139 @@
         <translation>Parts Generator</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="35"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="60"/>
         <source>Image</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="41"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="66"/>
         <source>week of the day</source>
         <translation>曜日</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="48"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="76"/>
         <source>calendar separator</source>
-        <translation>月日</translation>
+        <translation>月日(時分)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="55"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="86"/>
         <source>calendar number</source>
         <translation>数字 (カレンダー)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="62"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="96"/>
         <source>clock number</source>
         <translation>数字 (時計)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="89"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="127"/>
         <source>Config</source>
         <translation>設定</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="139"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="194"/>
         <source>Font size</source>
         <translation>フォントサイズ</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="95"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="133"/>
         <source>Font color</source>
         <translation>フォントの色</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="112"/>
-        <source>Outline color</source>
-        <translation>枠の色</translation>
-    </message>
-    <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="156"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="167"/>
         <source>Input text</source>
         <translation>タグ文字の入力</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="149"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="160"/>
         <source>Input</source>
         <translation>入力</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="166"/>
-        <source>Outline size</source>
-        <translation>枠の幅</translation>
-    </message>
-    <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="216"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="240"/>
         <source>Font</source>
         <translation>フォント</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="241"/>
-        <source>dummy</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="258"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="316"/>
         <source>&amp;File</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="313"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="371"/>
         <source>&amp;New</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="318"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="376"/>
         <source>&amp;Save</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="323"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="381"/>
         <source>&amp;Open</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="328"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="386"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="333"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="391"/>
         <source>&amp;Release</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="338"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="396"/>
         <source>&amp;Quit</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="341"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="399"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="270"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="328"/>
         <source>&amp;Help</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="346"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="404"/>
         <source>&amp;About</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="302"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="360"/>
         <source>toolBar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="PartsGeneratorWindowForm.ui" line="192"/>
+        <location filename="PartsGeneratorWindowForm.ui" line="177"/>
         <source>Background color</source>
         <translation>背景色</translation>
     </message>
+    <message>
+        <location filename="PartsGeneratorWindowForm.ui" line="204"/>
+        <source>Offset</source>
+        <translation>オフセット幅</translation>
+    </message>
+    <message>
+        <location filename="PartsGeneratorWindowForm.ui" line="266"/>
+        <source>Output file</source>
+        <translation>ファイル出力</translation>
+    </message>
+    <message>
+        <location filename="PartsGeneratorWindowForm.ui" line="256"/>
+        <source>dummy.png</source>
+        <translation>dummy.png</translation>
+    </message>
+    <message>
+        <location filename="PartsGeneratorWindowForm.ui" line="250"/>
+        <source>Output</source>
+        <translation>出力</translation>
+    </message>
 </context>
 </TS>
