@@ -52,6 +52,11 @@ public:
   void evaluate(void);
 
 signals:
+  /*!
+    \brief セルの更新
+
+    \param cell_index [i] 描画するセル
+  */
   void updateCell(int cell_index);
 };
 
