@@ -139,10 +139,10 @@ namespace {
     // 描画位置の計算
     int x, y;
     if (center_position) {
-      x = static_cast<int>((-round(size_width / 2.0) + offset.x())
-                           * scaling_percent / 100.0);
-      y = static_cast<int>((-round(size_height / 2.0) + offset.y())
-                           * scaling_percent / 100.0);
+      x = static_cast<int>(round(-(size_width / 2.0 * scaling_percent / 100.0)
+                                 + (offset.x() * scaling_percent / 100.0)));
+      y = static_cast<int>(round(-(size_height / 2.0 * scaling_percent / 100.0)
+                                 + (offset.y() * scaling_percent / 100.0)));
     } else {
       x = static_cast<int>(round(offset.x() * scaling_percent / 100.0));
       y = static_cast<int>(round(offset.y() * scaling_percent / 100.0));
@@ -207,6 +207,11 @@ namespace {
                hour, minute, (hour >= 12) ? 'P' : 'A');
     }
 
+    if (! resource.option.value("digital/ampm", "").compare("off")) {
+      // AM / PM を表示しない
+      buffer[9] = '_';
+    }
+
     if (resource.option.value("digital/colon", "").compare("on")) {
       // コロンを表示しない
       buffer[2] = ' ';
@@ -377,13 +382,24 @@ void ClockPartsDraw::updatePixmaps(QRegion& region,
     last_cell_index_ = cell_index;
   }
 
-  updateCalendar(region, resource, calendar_positions,
-                 date.month(), date.day(), date.dayOfWeek(), scaling_percent);
-  updateDigital(region, resource, digital_positions,
-                time.hour(), time.minute(), time.second(), scaling_percent);
+  // デジタル文字を手前に表示するかどうか
+  bool digital_above = resource.option.value("digital/above", "").compare("on");
+
+  if (! digital_above) {
+    updateCalendar(region, resource, calendar_positions,
+                   date.month(), date.day(), date.dayOfWeek(), scaling_percent);
+    updateDigital(region, resource, digital_positions,
+                  time.hour(), time.minute(), time.second(), scaling_percent);
+  }
   updateAnalog(region, resource,
                time.hour(), time.minute(), time.second(), scaling_percent);
   updateAdditional(region, resource, scaling_percent);
+  if (digital_above) {
+    updateCalendar(region, resource, calendar_positions,
+                   date.month(), date.day(), date.dayOfWeek(), scaling_percent);
+    updateDigital(region, resource, digital_positions,
+                  time.hour(), time.minute(), time.second(), scaling_percent);
+  }
 }
 
 
