@@ -46,6 +46,11 @@ private slots:
   */
   void setScalingPercent(int value);
 
+  /*!
+    \brief アニメーション しない / する を設定
+
+    \param checked [i] アニメーションしないときに true
+   */
   void setNoAnimationCheckbox(bool checked);
 
 
@@ -57,6 +62,11 @@ signals:
   */
   void scalingValueChanged(int percent);
 
+  /*!
+    \brief アニメーション しない / する の変更
+
+    \param checked [i] アニメーションしないときに true が渡される
+  */
   void noAnimationStateChanged(bool checked);
 };
 
