@@ -12,6 +12,7 @@
 #include <fstream>
 #include <string>
 #include "SettingConfig.h"
+#include "AnimationPattern.h"
 
 
 namespace {
@@ -151,6 +152,8 @@ struct SettingConfig::pImpl {
     tags_.insert("digital/colon", "on");
     tags_.insert("digital/blink", "on");
     tags_.insert("digital/sec", "on");
+    tags_.insert("digital/ampm", "on");
+    tags_.insert("digital/above", "on");
 
     tags_.insert("digital/ap_xpos", "0");
     tags_.insert("digital/ap_ypos", "0");
@@ -274,7 +277,7 @@ struct SettingConfig::pImpl {
     // デジタル情報
     const char* digital_tags[] = {
       "parts",
-      "colon", "blink", "sec",
+      "colon", "blink", "sec", "ampm", "above",
       "ap_xpos", "ap_ypos",
       "h1_xpos", "h1_ypos", "h2_xpos", "h2_ypos", "cl_xpos", "cl_ypos",
       "m1_xpos", "m1_ypos", "m2_xpos", "m2_ypos",
@@ -347,30 +350,22 @@ struct SettingConfig::pImpl {
 
     // セル情報
     for (size_t i = 0; i < AnimationCellMax; ++i) {
-      char name[] = "animation/cell_000/cell";
-      snprintf(name, strlen(name) + 1, "animation/cell_%03d/cell", i);
-
-      TagMap::iterator p = tags_.find(name);
+      AnimationCellTag tag_names(i);
+      TagMap::iterator p = tags_.find(tag_names.cell_tag);
       if (p == tags_.end()) {
         break;
       }
 
       // 書き出し処理
-      char tag_name[] = "cell_000";
-      snprintf(tag_name, strlen(tag_name) + 1, "cell_%03d", i);
-      fout << "    <" << tag_name << ">" << std::endl;
+      fout << "    <" << tag_names.simple_tag << ">" << std::endl;
       fout << "      <cell> " << p.value() << " </cell>" << std::endl;
 
-      char x_tag[] = "animation/cell_000/xpos";
-      char y_tag[] = "animation/cell_000/ypos";
-      size_t length = strlen(x_tag) + 1;
-      snprintf(x_tag, length, "animation/cell_%03d/xpos", i);
-      snprintf(y_tag, length, "animation/cell_%03d/ypos", i);
+      fout << "      <xpos> " << tags_[tag_names.xpos_tag] << " </xpos>"
+           << std::endl;
+      fout << "      <ypos> " << tags_[tag_names.ypos_tag] << " </ypos>"
+           << std::endl;
 
-      fout << "      <xpos> " << tags_[x_tag] << " </xpos>" << std::endl;
-      fout << "      <ypos> " << tags_[y_tag] << " </ypos>" << std::endl;
-
-      fout << "    </" << tag_name << ">" << std::endl;
+      fout << "    </" << tag_names.simple_tag << ">" << std::endl;
     }
     fout << std::endl;
 
@@ -378,37 +373,24 @@ struct SettingConfig::pImpl {
     for (size_t i = 0; i < AnimationCellMax; ++i) {
 
       // !!! 指定したタグがあるか、を判定する関数を作るべきかも
-      char name[] = "animation/pattern_000/pattern";
-      snprintf(name, strlen(name) + 1, "animation/pattern_%03d/pattern", i);
-
-      TagMap::iterator p = tags_.find(name);
+      AnimationPatternTag tag_names(i);
+      TagMap::iterator p = tags_.find(tag_names.pattern_tag);
       if (p == tags_.end()) {
         break;
       }
 
       // 書き出し処理
-      char tag_name[] = "pattern_000";
-      snprintf(tag_name, strlen(tag_name) + 1, "pattern_%03d", i);
+      double probability = atof(tags_[tag_names.probability_tag].c_str());
+      size_t cycle = atoi(tags_[tag_names.cycle_tag].c_str());
+      std::string pattern = tags_[tag_names.pattern_tag];
 
-      std::string probability_tag =
-        std::string("animation/") + tag_name + "/probability";
-      double probability = atof(tags_[probability_tag].c_str());
-
-      std::string cycle_tag =
-        std::string("animation/") + tag_name + "/cycle";
-      size_t cycle = atoi(tags_[cycle_tag].c_str());
-
-      std::string pattern_tag =
-        std::string("animation/") + tag_name + "/pattern";
-      std::string pattern = tags_[pattern_tag];
-
-      fout << "    <" << tag_name << ">" << std::endl;
+      fout << "    <" << tag_names.simple_tag << ">" << std::endl;
       fout << "      <probability> " << probability << " </probability>"
            << std::endl;
       fout << "      <cycle> " << cycle << " </cycle>" << std::endl;
       fout << "      <pattern> " << pattern << " </pattern>" << std::endl;
 
-      fout << "    </" << tag_name << ">" << std::endl;
+      fout << "    </" << tag_names.simple_tag << ">" << std::endl;
       fout << std::endl;
     }
 
