@@ -32,6 +32,11 @@
 #endif
 
 
+namespace {
+  typedef QMap<std::string, std::string> TagsMap;
+};
+
+
 struct ThemeClockDraw::pImpl {
 
   enum {
@@ -138,7 +143,7 @@ struct ThemeClockDraw::pImpl {
 
     // 設定ファイルの読み出し
     QByteArray data(p, size);
-    QMap<std::string, std::string> tags;
+    TagsMap tags;
     SettingConfig setting(tags, data);
 
     // 画像の格納
@@ -164,18 +169,16 @@ struct ThemeClockDraw::pImpl {
     loadOption(resource, "digital/colon", tags);
     loadOption(resource, "digital/blink", tags);
     loadOption(resource, "digital/sec", tags);
+    loadOption(resource, "digital/ampm", tags);
     loadOption(resource, "calendar/month", tags);
 
     // デジタル文字を、文字毎に格納
     loadDigitalCharacter(resource, tags, rrda_encoder);
-
-    // デジタル文字の描画位置を設定
     loadDigitalPosition(digital_positions_, tags);
 
     // カレンダー文字、曜日、セパレータを、文字毎に格納
     loadCalendarCharacter(resource, tags, rrda_encoder);
-
-    // カレンダー文字の描画位置を設定
+    loadSeparatorCharacter(resource, tags, rrda_encoder);
     loadCalendarPosition(calendar_positions_, tags);
 
     // 描画リソースが何もなければ、エラー
@@ -194,8 +197,7 @@ struct ThemeClockDraw::pImpl {
 
   // 画像の読み出し
   bool loadPixmap(ThemeResource& resource, const std::string& tag_name,
-                  const QMap<std::string, std::string>& tags,
-                  RrdaEncoder& rrda_encoder) {
+                  const TagsMap& tags, RrdaEncoder& rrda_encoder) {
 
     // タグ名の RRDA リソースからの取得
     std::string pixmap_tag_name = tags.value(tag_name, "");
@@ -226,7 +228,7 @@ struct ThemeClockDraw::pImpl {
   // 対応する画像が既に resouce に登録されていなければならない
   void loadOffset(ThemeResource& resource, const std::string& tag_name,
                   const std::string& x_tag, const std::string& y_tag,
-                  const QMap<std::string, std::string>& tags) {
+                  const TagsMap& tags) {
 
     // 位置の取得と登録
     int x = atoi(tags.value(x_tag, "0").c_str());
@@ -243,7 +245,7 @@ struct ThemeClockDraw::pImpl {
 
   // オプションの読み出し
   void loadOption(ThemeResource& resource, const std::string& tag_name,
-                  const QMap<std::string, std::string>& tags) {
+                  const TagsMap& tags) {
 
     // オプションの取得と登録
     std::string tag_value = tags.value(tag_name, "");
@@ -256,8 +258,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // デジタル画像の読み出し
-  void loadDigitalCharacter(ThemeResource& resource,
-                            QMap<std::string, std::string>& tags,
+  void loadDigitalCharacter(ThemeResource& resource, TagsMap& tags,
                             RrdaEncoder& rrda_encoder) {
 
     // 文字毎に等間隔で分割して登録する
@@ -273,8 +274,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // カレンダー用画像の読み出し
-  bool loadCalendarCharacter(ThemeResource& resource,
-                             QMap<std::string, std::string>& tags,
+  bool loadCalendarCharacter(ThemeResource& resource, TagsMap& tags,
                              RrdaEncoder& rrda_encoder) {
 
     // 数値文字の読み出し
@@ -298,12 +298,18 @@ struct ThemeClockDraw::pImpl {
                               week_pixmap_, "calendar/week", week_names, n)) {
       return false;
     }
+  }
+
+
+  // セパレータ用画像の読み出し
+  bool loadSeparatorCharacter(ThemeResource& resource, TagsMap& tags,
+                              RrdaEncoder& rrda_encoder) {
 
     // 区切り文字の読み出し
     const char* separator_names[] = {
       "MONTH", "DAY",
     };
-    n = sizeof(separator_names) / sizeof(separator_names[0]);
+    size_t n = sizeof(separator_names) / sizeof(separator_names[0]);
 
     if (! loadCharacterImages(resource, tags, rrda_encoder, separator_pixmap_,
                               "calendar/separator", separator_names, n)) {
@@ -315,8 +321,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // 文字画像の読み出し
-  bool loadCharacterImages(ThemeResource& resource,
-                           QMap<std::string, std::string>& tags,
+  bool loadCharacterImages(ThemeResource& resource, TagsMap& tags,
                            RrdaEncoder& rrda_encoder,
                            QVector<QPixmap>& pixmaps,
                            const char* image_tag,
@@ -355,8 +360,7 @@ struct ThemeClockDraw::pImpl {
 
 
   // アニメーション情報の読み出し
-  void loadAnimations(ThemeResource& resource,
-                      QMap<std::string, std::string>& tags,
+  void loadAnimations(ThemeResource& resource, TagsMap& tags,
                       RrdaEncoder& rrda_encoder) {
 
     // !!! 内部実装を、適当に関数化すること
@@ -368,28 +372,17 @@ struct ThemeClockDraw::pImpl {
     };
 
     for (size_t i = 0; i < AnimationCellMax; ++i) {
-      // タグが存在するかで枚数をカウント
-      char tag_name[] = "animation/cell_000/cell";
-      snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
 
-      if (! loadPixmap(resource, tag_name, tags, rrda_encoder)) {
+      // タグが存在するかで枚数をカウント
+      AnimationCellTag tag_names(i);
+      if (! loadPixmap(resource, tag_names.cell_tag, tags, rrda_encoder)) {
         break;
       }
 
       // セル位置の読み出し
-      char x_tag[] = "animation/cell_000/xpos";
-      char y_tag[] = "animation/cell_000/ypos";
-      size_t length = strlen(x_tag) + 1;
-      snprintf(x_tag, length, "animation/cell_%03d/xpos", i);
-      snprintf(y_tag, length, "animation/cell_%03d/ypos", i);
-
-      int x = atoi(tags[x_tag].c_str());
-      int y = atoi(tags[y_tag].c_str());
-      cell_positions_.push_back(QPoint(x, y));
-
-      // !!! とりあえず
-      // !!! いずれ、整合を取る
-      resource.offset.insert(tag_name, QRect(x, y, 0, 0));
+      int x = atoi(tags[tag_names.xpos_tag].c_str());
+      int y = atoi(tags[tag_names.ypos_tag].c_str());
+      resource.offset.insert(tag_names.cell_tag, QRect(x, y, 0, 0));
 
       cell_max_ = i + 1;
     }
@@ -397,33 +390,19 @@ struct ThemeClockDraw::pImpl {
     // アニメーションパターンの読み出し
     for (size_t i = 0; i < AnimationPatternMax; ++i) {
       // 順番に評価して、見つからなければ、終了
-      char tag_name[] = "animation/pattern_000/pattern";
-      snprintf(tag_name, strlen(tag_name) + 1,
-               "animation/pattern_%03d/pattern", i);
-
-      QMap<std::string, std::string>::iterator p = tags.find(tag_name);
+      AnimationPatternTag tag_names(i);
+      TagsMap::iterator p = tags.find(tag_names.pattern_tag);
       if (p == tags.end()) {
         break;
       }
 
       // パターン情報の登録
-      // !!! qtmclock_config にも同じコードがある。いずれ、くくる
       AnimationPattern animation;
+      animation.probability = atof(tags[tag_names.probability_tag].c_str());
+      animation.cycle_msec = atoi(tags[tag_names.cycle_tag].c_str());
 
-      char base_name[] = "pattern_000";
-      snprintf(base_name, strlen(base_name) + 1, "pattern_%03d", i);
-
-      std::string probability_name =
-        std::string("animation/") + base_name + "/probability";
-      animation.probability = atof(tags[probability_name].c_str());
-
-      std::string cycle_name = std::string("animation/") + base_name + "/cycle";
-      size_t cycle_msec = atoi(tags[cycle_name].c_str());
-      animation.cycle_msec = cycle_msec;
-
-      std::string pattern = std::string("animation/") + base_name + "/pattern";
       std::vector<std::string> tokens;
-      size_t n = qrk::split(tokens, tags[pattern], ", \t");
+      size_t n = qrk::split(tokens, tags[tag_names.pattern_tag], ", \t");
       for (size_t j = 0; j < n; ++j) {
         animation.cells.push_back(atoi(tokens[j].c_str()));
       }
@@ -467,7 +446,7 @@ struct ThemeClockDraw::pImpl {
                         const QMap<std::string, QRect>& offset,
                         const QVector<QPoint>& digital_positions,
                         const QVector<QPoint>& calendar_positions,
-                        const QMap<std::string, std::string>& option) {
+                        const TagsMap& option) {
 
     // 画像リソースの更新
     theme_resource_.pixmap = pixmaps;
@@ -534,8 +513,7 @@ bool ThemeClockDraw::loadThemeResource(const QMap<std::string, QPixmap*>&
                                        digital_positions,
                                        const QVector<QPoint>&
                                        calendar_positions,
-                                       const QMap<std::string, std::string>&
-                                       option) {
+                                       const TagsMap& option) {
 
   if (! pimpl->loadThemeResouce(pixmaps, offset,
                                 digital_positions, calendar_positions,
