@@ -117,6 +117,11 @@ public:
   */
   void updateScalingPercent(size_t percent);
 
+  /*!
+    \brief アニメーション する / しない の設定
+
+    \param on [i] アニメーションするとき true
+  */
   void setAnimationOn(bool on);
 
 signals:
