@@ -1,9 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ja_JP">
+<defaultcodec></defaultcodec>
 <context>
     <name>@default</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="173"/>
+        <location filename="ThemeClockWidget.cpp" line="175"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
@@ -16,7 +17,7 @@
         <translation>テーマ時計: 設定</translation>
     </message>
     <message>
-        <location filename="ClockSettingDialogForm.ui" line="95"/>
+        <location filename="ClockSettingDialogForm.ui" line="102"/>
         <source>&amp;Close</source>
         <translation>閉じる (&amp;C)</translation>
     </message>
@@ -45,16 +46,21 @@
         <source>%1 %</source>
         <translation>%1 %</translation>
     </message>
+    <message>
+        <location filename="ClockSettingDialogForm.ui" line="77"/>
+        <source>no animation.</source>
+        <translation>アニメーションなし.</translation>
+    </message>
 </context>
 <context>
     <name>QAction</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="172"/>
+        <location filename="ThemeClockWidget.cpp" line="174"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;x)</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="167"/>
+        <location filename="ThemeClockWidget.cpp" line="169"/>
         <source>Config</source>
         <translation>設定</translation>
     </message>
@@ -62,7 +68,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="54"/>
+        <location filename="ThemeClockDraw.cpp" line="71"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -70,12 +76,12 @@
 <context>
     <name>ThemeClockWidget</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="293"/>
+        <location filename="ThemeClockWidget.cpp" line="286"/>
         <source>qtmclock</source>
         <translation>qtmclock</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="294"/>
+        <location filename="ThemeClockWidget.cpp" line="287"/>
         <source>%1 is not correct theme file.</source>
         <translation>%1 はテーマファイルではありません.</translation>
     </message>
