@@ -45,13 +45,25 @@ struct ArchiveConfig::pImpl {
     release_file_ = "lm_clocktheme_xxxx.dat";
     rrda_key_ = "LMTC";
 
+    // 設定
     normal_data_["config"] = "./lm_tc.xml";
+
+    // 時計画像
     normal_data_["base"] = "./clock_base.png";
     normal_data_["digital"] = "./segment.png";
     normal_data_["hari_h"] = "./hand_h.png";
     normal_data_["hari_m"] = "./hand_m.png";
     normal_data_["hari_s"] = "./hand_s.png";
 
+    // カレンダー画像
+    normal_data_["days"] = "./days.png";
+    normal_data_["week"] = "./week.png";
+    normal_data_["separator"] = "./separator.png";
+
+    // 追加画像
+    normal_data_["near"] = "./near.png";
+
+    // 制限データ
     restricted_data_["dummy"] = "./archive_list.txt";
   }
 
