@@ -26,13 +26,29 @@ class PartsPlaceScene : public QGraphicsScene {
   std::auto_ptr<pImpl> pimpl;
 
 protected:
+  /*!
+	\brief イベント制御
+
+	\param mouseEvent [i/o] イベント
+  */
   void mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent);
 
 public:
+  /*!
+	\brief コンストラクタ
+
+	\param parent [i] 親ウィジット
+  */
   PartsPlaceScene(QObject* parent = 0);
   ~PartsPlaceScene(void);
 
 signals:
+  /*!
+    \brief クリック位置の送信シグナル
+
+    \param x [i] ウィジット内クリック X 値
+    \param y [i] ウィジット内クリック Y 値
+  */
   void clicked(int x, int y);
 };
 
