@@ -27,6 +27,11 @@ class PatternRegisterWidget
   struct pImpl;
   std::auto_ptr<pImpl> pimpl;
 
+private slots:
+  void probabilityChangedHandler(double value);
+  void cycleChangedHandler(int value);
+  void patternChangedHandler(const QString& text);
+
 public:
   /*!
 	\brief コンストラクタ
@@ -41,7 +46,7 @@ public:
 
 	\param name [i] パターン名
   */
-  void setName(const std::string& name);
+  void setName(const std::string& name, int index);
 
   /*!
 	\brief 発生確率の登録
@@ -63,6 +68,11 @@ public:
 	\param pattern [i] 再生パターン
    */
   void setPattern(const std::string& pattern);
+
+signals:
+  void probabilityChanged(int index, double probability);
+  void cycleChanged(int index, int cycle_msec);
+  void patternChanged(int index, const std::string& pattern);
 };
 
 #endif /* !PATTERN_REGISTER_WIDGET_H */
