@@ -11,6 +11,7 @@
 #include "ReleaseDataFile.h"
 #include "ArchiveConfig.h"
 #include "RrdaDecoder.h"
+#include "AnimationPattern.h"
 
 
 bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
@@ -43,12 +44,11 @@ bool releaseDataFile(const ArchiveConfig& archive_config, size_t cell_max) {
   // アニメーション用の画像データ
   for (size_t i = 0; i < cell_max; ++i) {
 
-    char tag_name[] = "cell_000";
-    snprintf(tag_name, strlen(tag_name) + 1, "cell_%03d", i);
-
-    const std::string value = archive_config.getNormalData(tag_name);
+    AnimationCellTag cell_tags(i);
+    const std::string value =
+      archive_config.getNormalData(cell_tags.simple_tag);
     if (! value.empty()) {
-      decoder.setNormalData(tag_name, value);
+      decoder.setNormalData(cell_tags.simple_tag, value);
     }
 
   }
