@@ -14,6 +14,9 @@
 ReleaseDialog::ReleaseDialog(QDialog* parent) : QDialog(parent) {
   setupUi(this);
 
+  // アイコンの適用
+  setWindowIcon(QIcon(":icons/qtmclock_config_icon"));
+
   // イベントの接続
   connect(this, SIGNAL(accepted()), this, SLOT(acceptedHandler()));
 }
