@@ -7,7 +7,7 @@
   $Id$
 
   \todo ファイルを逐次読み出しながら圧縮する実装に変更する
-  \todo zip の圧縮、解凍を抽出してクラス化する
+  \todo zip の圧縮、解凍を抽出してクラス化する。または、Qt のクラスを使う
   \todo アルゴリズムを用いたループ処理に変更する
 */
 
