@@ -28,6 +28,7 @@
 #include "ThemeResource.h"
 #include "PartsPlaceScene.h"
 #include "CellPreviewWidget.h"
+#include "AnimationPattern.h"
 #include "PatternRegisterWidget.h"
 
 using namespace qrk;
@@ -171,6 +172,10 @@ struct ThemeConfigWindow::pImpl {
     same_hands_center_ = parent->center_checkbox_->isChecked();
     connect(parent->month_checkbox_, SIGNAL(clicked(bool)),
             parent, SLOT(monthCheckHandler(bool)));
+    connect(parent->show_ampm_checkbox_, SIGNAL(clicked(bool)),
+            parent, SLOT(ampmCheckHandler(bool)));
+    connect(parent->digital_above_checkbox_, SIGNAL(clicked(bool)),
+            parent, SLOT(digitalAboveCheckHandler(bool)));
 
     // メニューイベントの接続
     connect(parent->action_exit_, SIGNAL(triggered()), parent, SLOT(close()));
@@ -464,13 +469,17 @@ struct ThemeConfigWindow::pImpl {
 
     // コロンの点滅 する / しない
     bool blink = ! setting_config_->getValue("digital/blink").compare("on");
-    parent->digital_checkbox_->setChecked(blink);
+    parent->blink_checkbox_->setChecked(blink);
 
     // カレンダー月の 表示 / 非表示
     bool calendar_month =
       ! setting_config_->getValue("calendar/month").compare("on");
     parent->month_checkbox_->setChecked(calendar_month);
 
+    // AM/PM の 表示 / 非表示
+    bool ampm = ! setting_config_->getValue("digital/ampm").compare("on");
+    parent->show_ampm_checkbox_->setChecked(ampm);
+
     // アニメーション情報の読み出し
     loadAnimations();
 
@@ -559,18 +568,15 @@ struct ThemeConfigWindow::pImpl {
     QTreeWidgetItem* animation_item = name_to_item_["animation"];
     for (size_t i = 0; i < AnimationCellMax; ++i) {
       // 順番に評価して、見つからなければ、終了
-      char tag_name[] = "animation/cell_000/cell";
-      snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
+      AnimationCellTag cell_tags(i);
 
       // アニメーション登録用のツリーを追加
-      char tree_name[] = "cell_000";
-      snprintf(tree_name, strlen(tree_name) + 1, "cell_%03d", i);
       QTreeWidgetItem* cell_item = new QTreeWidgetItem(animation_item);
-      cell_item->setText(0, tree_name);
+      cell_item->setText(0, cell_tags.simple_tag.c_str());
       cell_item->setCheckState(0, Qt::Unchecked);
-      registerTreeItem(tag_name, cell_item);
+      registerTreeItem(cell_tags.cell_tag, cell_item);
 
-      if (! loadImage(tag_name)) {
+      if (! loadImage(cell_tags.cell_tag.c_str())) {
         break;
       }
       cell_max_ = i + 1;
@@ -578,27 +584,17 @@ struct ThemeConfigWindow::pImpl {
 
     // アニメーション用画像の位置を、反映させる
     for (size_t i = 0; i < cell_max_; ++i) {
-      char tag_name[] = "animation/cell_000/cell";
-      snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
-
-      char x_tag[] = "animation/cell_000/xpos";
-      char y_tag[] = "animation/cell_000/ypos";
-      size_t length = strlen(x_tag) + 1;
-      snprintf(x_tag, length, "animation/cell_%03d/xpos", i);
-      snprintf(y_tag, length, "animation/cell_%03d/ypos", i);
-
-      int x = atoi(setting_config_->getValue(x_tag).c_str());
-      int y = atoi(setting_config_->getValue(y_tag).c_str());
-      parts_positions_[tag_name] = QPoint(x, y);
+      AnimationCellTag cell_tags(i);
+      int x = atoi(setting_config_->getValue(cell_tags.xpos_tag).c_str());
+      int y = atoi(setting_config_->getValue(cell_tags.ypos_tag).c_str());
+      parts_positions_[cell_tags.cell_tag] = QPoint(x, y);
     }
 
     // パターン情報の読み出し
     for (size_t i = 0; i < AnimationPatternMax; ++i) {
       // 順番に評価して、見つからなければ、終了
-      char tag_name[] = "animation/pattern_000/pattern";
-      snprintf(tag_name, strlen(tag_name) + 1,
-               "animation/pattern_%03d/pattern", i);
-      if (setting_config_->getValue(tag_name).empty()) {
+      AnimationPatternTag pattern_tags(i);
+      if (setting_config_->getValue(pattern_tags.pattern_tag).empty()) {
         break;
       }
 
@@ -613,23 +609,17 @@ struct ThemeConfigWindow::pImpl {
   // アニメーション情報の保存
   void saveAnimations(void) {
 
+    // セル情報の登録
     for (size_t i = 0; i < cell_max_; ++i) {
 
       // 位置の記録
-      char name[] = "animation/cell_000/cell";
-      snprintf(name, strlen(name) + 1, "animation/cell_%03d/cell", i);
-
-      char x_tag[] = "animation/cell_000/xpos";
-      char y_tag[] = "animation/cell_000/ypos";
-      size_t length = strlen(x_tag) + 1;
-      snprintf(x_tag, length, "animation/cell_%03d/xpos", i);
-      snprintf(y_tag, length, "animation/cell_%03d/ypos", i);
+      AnimationCellTag cell_tags(i);
 
       // XML ファイルへの記録
       position_tag_t tag;
-      tag.name = name;
-      tag.x_tag = x_tag;
-      tag.y_tag = y_tag;
+      tag.name = cell_tags.cell_tag.c_str();
+      tag.x_tag = cell_tags.xpos_tag.c_str();
+      tag.y_tag = cell_tags.ypos_tag.c_str();
       saveEachPosition(tag);
     }
   }
@@ -644,26 +634,26 @@ struct ThemeConfigWindow::pImpl {
     for (size_t i = 0; i < pattern_max_; ++i) {
 
       PatternRegisterWidget* widget = new PatternRegisterWidget(widget_parent);
+      connect(widget, SIGNAL(probabilityChanged(int, double)),
+              parent, SLOT(probabilityChangedHandler(int, double)));
+      connect(widget, SIGNAL(cycleChanged(int, int)),
+              parent, SLOT(cycleChangedHandler(int, int)));
+      connect(widget, SIGNAL(patternChanged(int, const std::string&)),
+              parent, SLOT(patternChangedHandler(int, const std::string&)));
 
       // 設定パターンを反映
-      char base_name[] = "pattern_000";
-      snprintf(base_name, strlen(base_name) + 1, "pattern_%03d", i);
+      AnimationPatternTag pattern_tags(i);
+      widget->setName(pattern_tags.simple_tag, i);
 
-      widget->setName(base_name);
-
-      std::string probability_name =
-        std::string("animation/") + base_name + "/probability";
       double probability =
-        atof(setting_config_->getValue(probability_name).c_str());
+        atof(setting_config_->getValue(pattern_tags.probability_tag).c_str());
       widget->setProbability(probability);
 
-      std::string cycle_name = std::string("animation/") + base_name + "/cycle";
-      size_t cycle = atoi(setting_config_->getValue(cycle_name).c_str());
+      size_t cycle =
+        atoi(setting_config_->getValue(pattern_tags.cycle_tag).c_str());
       widget->setCycle(cycle);
 
-      std::string pattern =
-        std::string("animation/") + base_name + "/pattern";
-      widget->setPattern(setting_config_->getValue(pattern));
+      widget->setPattern(setting_config_->getValue(pattern_tags.pattern_tag));
 
       parent->patterns_layout_->addWidget(widget);
       pattern_register_.push_back(widget);
@@ -671,6 +661,13 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
+  // アニメーションパターンの保存
+  void saveAnimationPatterns(ThemeConfigWindow* parent) {
+
+    // !!!
+  }
+
+
   // 数値部品の更新
   void updateDigitalParts(const QPixmap& pixmap) {
 
@@ -773,12 +770,11 @@ struct ThemeConfigWindow::pImpl {
 
     // アニメーション部品
     for (size_t i = 0; i < cell_max_; ++i) {
-      char tag_name[] = "animation/cell_000/cell";
-      snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
+      AnimationCellTag cell_tags(i);
 
       if ((! current_tag_.compare("animation")) ||
-          (name_to_item_[tag_name]->checkState(0) == Qt::Checked)) {
-        registerItem(parent, tag_name);
+          (name_to_item_[cell_tags.cell_tag]->checkState(0) == Qt::Checked)) {
+        registerItem(parent, cell_tags.cell_tag.c_str());
       }
     }
 
@@ -1180,11 +1176,8 @@ struct ThemeConfigWindow::pImpl {
     // アニメーション部品をまとめて移動させる
     if (! tag.compare("animation")) {
       for (size_t i = 0; i < cell_max_; ++i) {
-
-        // !!! タグを作る処理は、関数化して、くくるべきか？
-        char tag_name[] = "animation/cell_000/cell";
-        snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
-        updatePosition(parent, x, y, tag_name);
+        AnimationCellTag cell_tags(i);
+        updatePosition(parent, x, y, cell_tags.cell_tag);
       }
       return;
     }
@@ -1279,6 +1272,8 @@ struct ThemeConfigWindow::pImpl {
                   parent->show_colon_checkbox_->isChecked() ? "on" : "off");
     option.insert("digital/blink",
                   parent->blink_checkbox_->isChecked() ? "on" : "off");
+    option.insert("digital/ampm",
+                  parent->show_ampm_checkbox_->isChecked() ? "on" : "off");
     option.insert("calendar/month",
                   parent->month_checkbox_->isChecked() ? "on" : "off");
 
@@ -1452,12 +1447,44 @@ struct ThemeConfigWindow::pImpl {
       previewOpened(parent);
     }
   }
+
+
+  // 設定の読み出し
+  void readSettings(ThemeConfigWindow* parent) {
+
+    QSettings settings("Hyakuren Soft LTD.", "qtmclock_config");
+
+    // ウィンドウの位置と場所
+    QRect position = settings.value("geometry", parent->geometry()).toRect();
+    parent->setGeometry(position);
+
+    // 前回起動時に、どちらのタブが開かれていたかを読み出す
+    int mode_tab_index = settings.value("mode_tab", 0).toInt();
+    parent->mode_tab_->setCurrentIndex(mode_tab_index);
+  }
+
+
+  // 設定の保存
+  void writeSettings(ThemeConfigWindow* parent) {
+
+    QSettings settings("Hyakuren Soft LTD.", "qtmclock_config");
+
+    // ウィンドウの位置と場所
+    QRect position = parent->geometry();
+    QSize size = parent->size();
+    settings.setValue("geometry", QRect(position.x(), position.y(),
+                                        size.width(), size.height()));
+
+    // 最後に、どちらのタブが開かれていたかを記録する
+    settings.setValue("mode_tab", parent->mode_tab_->currentIndex());
+  }
 };
 
 
 ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
   : pimpl(new pImpl) {
   setupUi(this);
+  pimpl->readSettings(this);
 
   // ツールバーの初期化
   pimpl->new_act_ = new QAction(QIcon(":icons/new_icon"), tr("New"), this);
@@ -1497,12 +1524,6 @@ ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
   // ツリー構成の取得
   pimpl->treeTagInitialize(this);
 
-  // 最後に、どちらのタブが開かれていたかを読み出す
-  QSettings settings("Hyakuren Soft LTD.", "qtmclock_config");
-  int mode_tab_index = settings.value("mode_tab", 0).toInt();
-  // 前回の設定を反映させる
-  mode_tab_->setCurrentIndex(mode_tab_index);
-
   // ファイルが指定されていれば、読み出し
   if (! config_file.isEmpty()) {
     pimpl->loadArchiveFile(this, config_file.toStdString());
@@ -1518,9 +1539,7 @@ ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
 
 ThemeConfigWindow::~ThemeConfigWindow(void) {
 
-  // 最後に、どちらのタブが開かれていたかを記録する
-  QSettings settings("Hyakuren Soft LTD.", "qtmclock_config");
-  settings.setValue("mode_tab", mode_tab_->currentIndex());
+  pimpl->writeSettings(this);
 }
 
 
@@ -1699,9 +1718,8 @@ void ThemeConfigWindow::updateAnimationItems(QTreeWidgetItem* item,
 
     for (size_t i = 0; i < pimpl->cell_max_; ++i) {
       // 指定セル以外は閉じる
-      char tag_name[] = "animation/cell_000/cell";
-      snprintf(tag_name, strlen(tag_name) + 1, "animation/cell_%03d/cell", i);
-      QTreeWidgetItem* compare_item = pimpl->name_to_item_[tag_name];
+      AnimationCellTag cell_tags(i);
+      QTreeWidgetItem* compare_item = pimpl->name_to_item_[cell_tags.cell_tag];
       if (compare_item != item) {
         compare_item->setCheckState(0, Qt::Unchecked);
       }
@@ -1741,6 +1759,7 @@ void ThemeConfigWindow::blinkCheckHandler(bool checked) {
 void ThemeConfigWindow::analogCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("analog/sec", checked ? "on" : "off");
+  pimpl->updateItems();
   pimpl->applyCheckChanged(this);
 }
 
@@ -1749,6 +1768,7 @@ void ThemeConfigWindow::analogCheckHandler(bool checked) {
 void ThemeConfigWindow::digitalCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("digital/sec", checked ? "on" : "off");
+  pimpl->updateItems();
   pimpl->applyCheckChanged(this);
 }
 
@@ -1757,6 +1777,25 @@ void ThemeConfigWindow::digitalCheckHandler(bool checked) {
 void ThemeConfigWindow::monthCheckHandler(bool checked) {
 
   pimpl->setting_config_->setValue("calendar/month", checked ? "on" : "off");
+  pimpl->updateItems();
+  pimpl->applyCheckChanged(this);
+}
+
+
+// AM / PM を表示するか、の設定
+void ThemeConfigWindow::ampmCheckHandler(bool checked) {
+
+  pimpl->setting_config_->setValue("digital/ampm", checked ? "on" : "off");
+  pimpl->updateItems();
+  pimpl->applyCheckChanged(this);
+}
+
+
+// デジタル表示をアナログ針よりも手前に表示するか、の設定
+void ThemeConfigWindow::digitalAboveCheckHandler(bool checked) {
+
+  pimpl->setting_config_->setValue("digital/above", checked ? "on" : "off");
+  pimpl->updateItems();
   pimpl->applyCheckChanged(this);
 }
 
@@ -1897,3 +1936,47 @@ void ThemeConfigWindow::partsClickedHandler(int x, int y) {
 
 
 // !!! Qt Demo の 画像のパズルを参考に、部品配置を変更するあたりを実装する
+
+
+// 確率の変更
+void ThemeConfigWindow::probabilityChangedHandler(int index,
+                                                  double probability) {
+
+  char probability_str[] = "1000.000";
+  snprintf(probability_str, sizeof(probability_str), "%.3f", probability);
+
+  AnimationPatternTag pattern_tags(index);
+  pimpl->setting_config_->
+    setValue(pattern_tags.probability_tag, probability_str);
+
+  // 保存可能にする
+  pimpl->setSaveEnabled(this, true);
+}
+
+
+// 動作周期の変更
+void ThemeConfigWindow::cycleChangedHandler(int index, int cycle_msec) {
+
+  char cycle_msec_str[] = "10000";
+  snprintf(cycle_msec_str, sizeof(cycle_msec_str), "%d", cycle_msec);
+
+  AnimationPatternTag pattern_tags(index);
+  pimpl->setting_config_->
+    setValue(pattern_tags.cycle_tag, cycle_msec_str);
+
+  // 保存可能にする
+  pimpl->setSaveEnabled(this, true);
+}
+
+
+// パターンの変更
+void ThemeConfigWindow::patternChangedHandler(int index,
+                                              const std::string& pattern) {
+
+  AnimationPatternTag pattern_tags(index);
+  pimpl->setting_config_->
+    setValue(pattern_tags.pattern_tag, pattern);
+
+  // 保存可能にする
+  pimpl->setSaveEnabled(this, true);
+}
