@@ -45,6 +45,8 @@ private slots:
   void analogCheckHandler(bool checked);
   void digitalCheckHandler(bool checked);
   void monthCheckHandler(bool checked);
+  void ampmCheckHandler(bool checked);
+  void digitalAboveCheckHandler(bool checked);
 
   void leftPressed(void);
   void rightPressed(void);
@@ -62,6 +64,10 @@ private slots:
   void partsClickedHandler(int x, int y);
   void updateAnimationItems(QTreeWidgetItem* item, int column);
 
+  void probabilityChangedHandler(int index, double probability);
+  void cycleChangedHandler(int index, int cycle_msec);
+  void patternChangedHandler(int index, const std::string& pattern);
+
 public:
 
   /*!
