@@ -24,12 +24,12 @@
         <translation>/ 秒</translation>
     </message>
     <message>
-        <location filename="PatternRegisterWidgetForm.ui" line="136"/>
+        <location filename="PatternRegisterWidgetForm.ui" line="145"/>
         <source>Pattern</source>
         <translation>パターン</translation>
     </message>
     <message>
-        <location filename="PatternRegisterWidgetForm.ui" line="156"/>
+        <location filename="PatternRegisterWidgetForm.ui" line="165"/>
         <source>Preview</source>
         <translation>プレビュー</translation>
     </message>
@@ -39,7 +39,7 @@
         <translation>再生周期</translation>
     </message>
     <message>
-        <location filename="PatternRegisterWidgetForm.ui" line="114"/>
+        <location filename="PatternRegisterWidgetForm.ui" line="123"/>
         <source>msec</source>
         <translation>ミリ秒</translation>
     </message>
@@ -47,7 +47,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="../qtmclock/ThemeClockDraw.cpp" line="56"/>
+        <location filename="../qtmclock/ThemeClockDraw.cpp" line="77"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -78,97 +78,97 @@
         <translation>Theme Config</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="273"/>
+        <location filename="ThemeConfigWindowForm.ui" line="311"/>
         <source>long hand</source>
         <translation>長針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="250"/>
+        <location filename="ThemeConfigWindowForm.ui" line="288"/>
         <source>base</source>
         <translation>ベース</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="265"/>
+        <location filename="ThemeConfigWindowForm.ui" line="303"/>
         <source>short hand</source>
         <translation>短針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="281"/>
+        <location filename="ThemeConfigWindowForm.ui" line="319"/>
         <source>second hand</source>
         <translation>秒針</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="290"/>
+        <location filename="ThemeConfigWindowForm.ui" line="328"/>
         <source>digital character</source>
         <translation>デジタル文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="590"/>
+        <location filename="ThemeConfigWindowForm.ui" line="628"/>
         <source>toolbar</source>
         <translation>ツールバー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="297"/>
+        <location filename="ThemeConfigWindowForm.ui" line="335"/>
         <source>hour</source>
         <translation>時</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="321"/>
+        <location filename="ThemeConfigWindowForm.ui" line="359"/>
         <source>minute</source>
         <translation>分</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="337"/>
+        <location filename="ThemeConfigWindowForm.ui" line="375"/>
         <source>second</source>
         <translation>秒</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="353"/>
+        <location filename="ThemeConfigWindowForm.ui" line="391"/>
         <source>AM/PM</source>
         <translation>AM/PM</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="313"/>
+        <location filename="ThemeConfigWindowForm.ui" line="351"/>
         <source>colon</source>
         <translation>コロン</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="240"/>
+        <location filename="ThemeConfigWindowForm.ui" line="278"/>
         <source>Node</source>
         <translation>項目</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="245"/>
+        <location filename="ThemeConfigWindowForm.ui" line="283"/>
         <source>Value</source>
         <translation>画像</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="608"/>
+        <location filename="ThemeConfigWindowForm.ui" line="646"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1453"/>
+        <location filename="ThemeConfigWindow.cpp" line="1481"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="620"/>
+        <location filename="ThemeConfigWindowForm.ui" line="658"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1457"/>
+        <location filename="ThemeConfigWindow.cpp" line="1485"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="632"/>
+        <location filename="ThemeConfigWindowForm.ui" line="670"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1461"/>
+        <location filename="ThemeConfigWindow.cpp" line="1489"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
@@ -178,7 +178,7 @@
         <translation>長針、短針、秒針の中心を揃える.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="258"/>
+        <location filename="ThemeConfigWindowForm.ui" line="296"/>
         <source>analog parts</source>
         <translation>アナログ部品</translation>
     </message>
@@ -188,242 +188,242 @@
         <translation>再生 / 停止</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="543"/>
+        <location filename="ThemeConfigWindowForm.ui" line="581"/>
         <source>File (&amp;F)</source>
         <translation>ファイル (&amp;F)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="556"/>
+        <location filename="ThemeConfigWindowForm.ui" line="594"/>
         <source>Edit (&amp;E)</source>
         <translation>編集 (&amp;E)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="562"/>
+        <location filename="ThemeConfigWindowForm.ui" line="600"/>
         <source>Help (&amp;H)</source>
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1452"/>
+        <location filename="ThemeConfigWindow.cpp" line="1480"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1456"/>
+        <location filename="ThemeConfigWindow.cpp" line="1484"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1460"/>
+        <location filename="ThemeConfigWindow.cpp" line="1488"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="637"/>
+        <location filename="ThemeConfigWindowForm.ui" line="675"/>
         <source>Release (&amp;R)</source>
         <translation>リリース (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="642"/>
+        <location filename="ThemeConfigWindowForm.ui" line="680"/>
         <source>Exit (&amp;Q)</source>
         <translation>終了 (&amp;Q)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="645"/>
+        <location filename="ThemeConfigWindowForm.ui" line="683"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="650"/>
+        <location filename="ThemeConfigWindowForm.ui" line="688"/>
         <source>Save as</source>
         <translation>名前を付けて保存</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="655"/>
+        <location filename="ThemeConfigWindowForm.ui" line="693"/>
         <source>Preview (&amp;R)</source>
         <translation>プレビュー (&amp;R)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="658"/>
+        <location filename="ThemeConfigWindowForm.ui" line="696"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="663"/>
+        <location filename="ThemeConfigWindowForm.ui" line="701"/>
         <source>About (&amp;A)</source>
         <translation>このアプリケーションについて (&amp;A)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="304"/>
+        <location filename="ThemeConfigWindowForm.ui" line="342"/>
         <source>h2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="328"/>
+        <location filename="ThemeConfigWindowForm.ui" line="366"/>
         <source>m2</source>
         <translation>位置 (100 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="344"/>
+        <location filename="ThemeConfigWindowForm.ui" line="382"/>
         <source>s2</source>
         <translation>位置 (1の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="163"/>
+        <location filename="ThemeConfigWindowForm.ui" line="197"/>
         <source>blink digital colon.</source>
         <translation>デジタル文字のコロンを点滅させる.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="183"/>
+        <location filename="ThemeConfigWindowForm.ui" line="207"/>
         <source>show digital second.</source>
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1544"/>
+        <location filename="ThemeConfigWindow.cpp" line="1567"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1586"/>
+        <location filename="ThemeConfigWindow.cpp" line="1609"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1584"/>
+        <location filename="ThemeConfigWindow.cpp" line="1607"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="605"/>
+        <location filename="ThemeConfigWindowForm.ui" line="643"/>
         <source>New (&amp;N)</source>
         <translation>新規作成 (&amp;N)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="617"/>
+        <location filename="ThemeConfigWindowForm.ui" line="655"/>
         <source>Open (&amp;O)</source>
         <translation>開く (&amp;O)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="629"/>
+        <location filename="ThemeConfigWindowForm.ui" line="667"/>
         <source>Save (&amp;S)</source>
         <translation>保存 (&amp;S)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="471"/>
+        <location filename="ThemeConfigWindowForm.ui" line="509"/>
         <source>Parts image</source>
         <translation>部品画像の更新</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="481"/>
+        <location filename="ThemeConfigWindowForm.ui" line="519"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="173"/>
+        <location filename="ThemeConfigWindowForm.ui" line="156"/>
         <source>show analog second.</source>
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1827"/>
+        <location filename="ThemeConfigWindow.cpp" line="1852"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1829"/>
+        <location filename="ThemeConfigWindow.cpp" line="1854"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1665"/>
+        <location filename="ThemeConfigWindow.cpp" line="1688"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1669"/>
+        <location filename="ThemeConfigWindow.cpp" line="1692"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="ThemeConfigWindowForm.ui" line="126"/>
-        <source>Clock</source>
-        <translation>時計</translation>
+        <source>Analog Clock</source>
+        <translation>アナログ時計</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="137"/>
+        <location filename="ThemeConfigWindowForm.ui" line="184"/>
         <source>Clock Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="205"/>
+        <location filename="ThemeConfigWindowForm.ui" line="243"/>
         <source>Calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="211"/>
+        <location filename="ThemeConfigWindowForm.ui" line="249"/>
         <source>Calendar Settings</source>
         <translation>描画設定</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="362"/>
+        <location filename="ThemeConfigWindowForm.ui" line="400"/>
         <source>calendar</source>
         <translation>カレンダー</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="376"/>
+        <location filename="ThemeConfigWindowForm.ui" line="414"/>
         <source>month</source>
         <translation>月</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="400"/>
+        <location filename="ThemeConfigWindowForm.ui" line="438"/>
         <source>day</source>
         <translation>日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="433"/>
+        <location filename="ThemeConfigWindowForm.ui" line="471"/>
         <source>day of the week</source>
         <translation>曜日</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="220"/>
+        <location filename="ThemeConfigWindowForm.ui" line="258"/>
         <source>show month.</source>
         <translation>月を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="369"/>
+        <location filename="ThemeConfigWindowForm.ui" line="407"/>
         <source>number</source>
         <translation>数値</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="391"/>
+        <location filename="ThemeConfigWindowForm.ui" line="429"/>
         <source>month_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="407"/>
+        <location filename="ThemeConfigWindowForm.ui" line="445"/>
         <source>c_d2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="415"/>
+        <location filename="ThemeConfigWindowForm.ui" line="453"/>
         <source>day_separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="425"/>
+        <location filename="ThemeConfigWindowForm.ui" line="463"/>
         <source>separator</source>
         <translation>区切り文字</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="383"/>
+        <location filename="ThemeConfigWindowForm.ui" line="421"/>
         <source>c_m2</source>
         <translation>位置 (1 の位)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="442"/>
+        <location filename="ThemeConfigWindowForm.ui" line="480"/>
         <source>additional</source>
         <translation>追加部品</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="449"/>
+        <location filename="ThemeConfigWindowForm.ui" line="487"/>
         <source>near</source>
         <translation>手前</translation>
     </message>
@@ -433,19 +433,34 @@
         <translation>配置</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="458"/>
+        <location filename="ThemeConfigWindowForm.ui" line="496"/>
         <source>animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="501"/>
+        <location filename="ThemeConfigWindowForm.ui" line="539"/>
         <source>Animation</source>
         <translation>アニメーション</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindowForm.ui" line="156"/>
+        <location filename="ThemeConfigWindowForm.ui" line="190"/>
         <source>show digital colon.</source>
         <translation>デジタル文字のコロンを表示する.</translation>
     </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="178"/>
+        <source>Digital Clock</source>
+        <translation>デジタル時計</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="217"/>
+        <source>show AM/PM.</source>
+        <translation>AM / PM を表示する.</translation>
+    </message>
+    <message>
+        <location filename="ThemeConfigWindowForm.ui" line="224"/>
+        <source>show digital above analog hands.</source>
+        <translation>デジタル表示をアナログ針よりも手前に表示する.</translation>
+    </message>
 </context>
 </TS>
